.. pandokia documentation master file, created by
   sphinx-quickstart on Fri Nov 13 10:58:31 2009.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Pandokia 
======================

.. toctree::
    :maxdepth: 2

    intro.rst
    install.rst
    pdk_aware.rst
    run_tests.rst
    file_format.rst
    report_fields.rst
    runners.rst
    helpers.rst
    adding_runners.rst
    database.rst
    vocabulary.rst
    demo.rst
    faq.rst
    programming.rst
    environment.rst
    tools.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

